@@ -1,4 +1,4 @@
-require 'backports/tools'
+require 'backports/tools/alias_method'
 
 class << ARGF
   Backports.alias_method self, :lines, :each_line
