@@ -1,5 +1,5 @@
 unless Enumerable.method_defined? :count
-  require 'backports/tools'
+  require 'backports/tools/arguments'
 
   module Enumerable
     def count(item = Backports::Undefined)
